﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Linq;

using  Autodesk.Revit .DB;
using Autodesk.Revit.DB.Architecture;
using Autodesk.Revit.UI;
using Autodesk.Revit .ApplicationServices;
using Autodesk.Revit.Attributes ;
using Autodesk.Revit.UI.Selection;


  [TransactionAttribute(Autodesk.Revit.Attributes.TransactionMode.Manual)]
public class FilterWallRoomsInLevel : IExternalCommand
{
    public Result Execute(ExternalCommandData commandData, ref string messages, ElementSet elements)
    {

      UIApplication app = commandData.Application;
      Document document = app.ActiveUIDocument.Document;
      
      // Use ElementLevel filter to find elements by their associated level in the document
      // Find the level whose Name is "Level 1"
      FilteredElementCollector collector = new FilteredElementCollector(document);
      ICollection<Element> levels = collector.OfClass(typeof(Level)).ToElements();
      var query = from element in collector where element.Name == "Level 1" select element;// Linq query

      // Get the level id which will be used to match elements
      List<Element> level1 = query.ToList<Element>();
      ElementId levelId = level1[0].Id;

      // Find all walls on level one
      ElementLevelFilter level1Filter = new ElementLevelFilter(levelId);
      collector = new FilteredElementCollector(document);
      ICollection<Element> allWallsOnLevel1 = collector.OfClass(typeof(Wall)).WherePasses(level1Filter).ToElements();
            
      TaskDialog.Show("Number of walls in Level 1", allWallsOnLevel1.Count.ToString());

      // Find all rooms not on level one: use an inverted ElementLevelFilter to match all elements not on the target level
      ElementLevelFilter notOnLevel1Filter = new ElementLevelFilter(levelId, true); // Inverted filter
      collector = new FilteredElementCollector(document);
      IList<Element> allRoomsNotOnLevel1 = collector.WherePasses(new RoomFilter()).WherePasses(notOnLevel1Filter).ToElements();

      
      Selection sel = app.ActiveUIDocument.Selection;
      sel.Elements.Clear();
      foreach (Element elem in allRoomsNotOnLevel1)
        sel.Elements.Add(elem);

      //TaskDialog.Show("Number of rooms not in Level 1", allRoomsNotOnLevel1.Count.ToString());
      return Result.Succeeded ;
    }
}